@@ -11,7 +11,7 @@ from serde.json import from_json
 from serde.yaml import from_yaml
 from smart_open import open
 
-from metaphor.common.logging import get_logger
+from metaphor.common.logger import get_logger
 
 from .api_sink import ApiSink, ApiSinkConfig
 from .file_sink import FileSink, FileSinkConfig
@@ -65,7 +65,7 @@ class BaseExtractor(ABC):
         events: List[MetadataChangeEvent] = asyncio.run(self.extract(config))
 
         logger.info(
-            f"Fetched {len(events)} entities, took {time.time() - start_time} s"
+            f"Fetched {len(events)} entities, took {format(time.time() - start_time, '.1f')} s"
         )
 
         if config.output.api is not None:
